@@ -399,6 +399,21 @@ gweather_info_reset (GWeatherInfo *info)
     priv->radar = NULL;
 }
 
+static void
+settings_changed_cb (GSettings    *settings,
+		     const char   *key,
+		     GWeatherInfo *info)
+{
+    GWeatherInfoPrivate *priv = info->priv;
+
+    /* Only emit the signal if no network requests are pending.
+       Otherwise just wait for the update that will happen at
+       the end
+    */
+    if (priv->requests_pending == 0)
+        g_signal_emit (info, gweather_info_signals[SIGNAL_UPDATED], 0);
+}
+
 void
 gweather_info_init (GWeatherInfo *info)
 {
@@ -407,6 +422,10 @@ gweather_info_init (GWeatherInfo *info)
     priv = info->priv = G_TYPE_INSTANCE_GET_PRIVATE (info, GWEATHER_TYPE_INFO, GWeatherInfoPrivate);
 
     priv->settings = g_settings_new ("org.gnome.GWeather");
+
+    g_signal_connect_object (priv->settings, "changed",
+			     G_CALLBACK (settings_changed_cb), info, 0);
+
     priv->radar_url = g_settings_get_string (priv->settings, RADAR_KEY);
     if (g_strcmp0 (priv->radar_url, "") == 0) {
 	g_free (priv->radar_url);
@@ -1950,7 +1969,7 @@ gweather_info_set_location_internal (GWeatherInfo     *info,
 	priv->world = gweather_location_ref_world (location);
 
     if (!priv->world)
-	priv->world = gweather_location_new_world (FALSE);
+	priv->world = gweather_location_new_world (TRUE);
 
     priv->glocation = location;
     if (priv->glocation) {
@@ -2098,7 +2117,7 @@ gweather_info_class_init (GWeatherInfoClass *klass)
 				"World",
 				"The hierarchy of locations containing the desired location",
 				GWEATHER_TYPE_LOCATION,
-				G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
+				G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_DEPRECATED);
     g_object_class_install_property (gobject_class, PROP_WORLD, pspec);
 
     pspec = g_param_spec_boxed ("location",
@@ -2181,6 +2200,9 @@ gweather_info_new (GWeatherLocation    *location,
  * GSettings) belongs.
  *
  * Returns: (transfer full): a new #GWeatherInfo
+ *
+ * Deprecated: there is only one world-level #GWeatherLocation at any time, so
+ *             this is the same as gweather_info_new().
  */
 GWeatherInfo *
 gweather_info_new_for_world (GWeatherLocation    *world,
